
# Type: has total


total number of things in a particular reference set

URI: [biolink:has_total](https://w3id.org/biolink/vocab/has_total)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [Integer](types/Integer.md)

## Parents

 *  is_a: [aggregate statistic](aggregate_statistic.md)

## Children

 *  [variant to population association➞has total](variant_to_population_association_has_total.md)

## Used by

 * [FrequencyQuantifier](FrequencyQuantifier.md)
 * [VariantToPopulationAssociation](VariantToPopulationAssociation.md)
